Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(343)

Unified Diff: pkg/analysis_server/lib/src/services/completion/dart/contribution_sorter.dart

Issue 1470863003: Rework contribution sorter to use futures (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: merge Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/src/services/completion/dart/contribution_sorter.dart
diff --git a/pkg/analysis_server/lib/src/services/completion/contribution_sorter.dart b/pkg/analysis_server/lib/src/services/completion/dart/contribution_sorter.dart
similarity index 69%
rename from pkg/analysis_server/lib/src/services/completion/contribution_sorter.dart
rename to pkg/analysis_server/lib/src/services/completion/dart/contribution_sorter.dart
index dbf995b4114f48b8c1b6912ef8033d236295726f..8279be35eb4c9c8c8392e70546b47f019ac0bd06 100644
--- a/pkg/analysis_server/lib/src/services/completion/contribution_sorter.dart
+++ b/pkg/analysis_server/lib/src/services/completion/dart/contribution_sorter.dart
@@ -2,25 +2,25 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library services.completion.sorter;
+library services.completion.dart.sorter;
+
+import 'dart:async';
import 'package:analysis_server/plugin/protocol/protocol.dart';
import 'package:analysis_server/src/provisional/completion/completion_core.dart';
/**
* The abstract class `ContributionSorter` defines the behavior of objects
* that are used to adjust the relevance of an existing list of suggestions.
* This is a long-lived object that should not maintain state between
* calls to it's [sort] method.
*/
-abstract class ContributionSorter {
+abstract class DartContributionSorter {
/**
* After [CompletionSuggestion]s have been computed,
* this method is called to adjust the relevance of those suggestions.
- * Return an [AnalysisRequest] if more analysis is needed,
- * or `null` if suggestion sorting is complete.
- * This method should execute quickly and not block.
+ * Return a [Future] that completes when the suggestions have been updated.
*/
- AnalysisRequest sort(
+ Future sort(
CompletionRequest request, Iterable<CompletionSuggestion> suggestions);
}
@@ -2,25 +2,25 @@
import 'package:analysis_server/src/provisional/completion/completion_core.dart';
/**
- * The abstract class `ContributionSorter` defines the behavior of objects
+ * The abstract class [DartContributionSorter] defines the behavior of objects
* that are used to adjust the relevance of an existing list of suggestions.
* This is a long-lived object that should not maintain state between

Powered by Google App Engine
This is Rietveld 408576698